# ResponseStatus


## Enum

* `SUCCESS` (value: `'success'`)

* `ERROR` (value: `'error'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


